"use strict";

var compareSnapshotCommand = function compareSnapshotCommand(defaultScreenshotOptions) {
  var height = process.env.HEIGHT || '1280';
  var width = process.env.WIDTH || '720'; // Disable duplicate screenshot on failure of visual regression test

  Cypress.Screenshot.defaults({
    screenshotOnRunFailure: false
  }); // Force screenshot resolution to keep consistency of test runs across machines

  Cypress.config('viewportHeight', height);
  Cypress.config('viewportWidth', width);
  Cypress.Commands.add('compareSnapshot', {
    prevSubject: 'optional'
  }, function (subject, name) {
    var testThreshold = arguments.length > 2 && arguments[2] !== undefined ? arguments[2] : 0;
    var specName = Cypress.spec.name;
    var testName = "".concat(specName.replace('.js', ''), "-").concat(name); // Take a screenshot and copy to baseline if it does not exist

    var objToOperateOn = subject ? cy.get(subject) : cy;
    objToOperateOn.screenshot(testName, defaultScreenshotOptions).task('copyScreenshot', {
      testName: testName
    }); // Compare screenshots

    var options = {
      testName: testName,
      testThreshold: testThreshold
    };
    cy.task('compareSnapshotsPlugin', options).then(function (percentage) {
      if (percentage > testThreshold) {
        throw new Error("The image difference percentage ".concat(percentage, " exceeded the threshold: ").concat(testThreshold));
      }
    });
  });
};

module.exports = compareSnapshotCommand;